@@ -1,11 +1,11 @@
-#!/usr/bin/env python
-
 """test_hello_pure
 ----------------------------------
 
 Tries to build and test the `hello-pure` sample project.
 """
 
+from __future__ import annotations
+
 import glob
 
 from skbuild.constants import SKBUILD_DIR
