@@ -1,11 +1,11 @@
-#!/usr/bin/env python
-
 """test_skbuild
 ----------------------------------
 
 Tests for `skbuild` module.
 """
 
+from __future__ import annotations
+
 import os
 import platform
 import sys
@@ -43,12 +43,10 @@ def test_generator_selection():
 
         # As of Dec 2016, this is available only for VS 9.0
         has_vs_for_python_vcvars = any(
-            [
-                os.path.exists(os.path.expanduser(path_pattern % vs_version))
-                for path_pattern in [
-                    "~/AppData/Local/Programs/Common/Microsoft/Visual C++ for Python/%.1f/vcvarsall.bat",
-                    "C:/Program Files (x86)/Common Files/Microsoft/Visual C++ for Python/%.1f/vcvarsall.bat",
-                ]
+            os.path.exists(os.path.expanduser(path_pattern % vs_version))
+            for path_pattern in [
+                "~/AppData/Local/Programs/Common/Microsoft/Visual C++ for Python/%.1f/vcvarsall.bat",
+                "C:/Program Files (x86)/Common Files/Microsoft/Visual C++ for Python/%.1f/vcvarsall.bat",
             ]
         )
 
@@ -147,7 +145,7 @@ def test_platform_windows_find_visual_studio(vs_year, capsys):
             print(f"\nFound VS {vs_year} @ {vs_path}")
         assert os.path.exists(vs_path)
     else:
-        assert vs_path == ""
+        assert not vs_path
 
 
 @pytest.mark.skipif(sys.platform != "win32", reason="Requires Windows")
